@@ -5,10 +5,6 @@ class RedisError(Exception):
     pass
 
 
-class AuthenticationError(RedisError):
-    pass
-
-
 class ConnectionError(RedisError):
     pass
 
@@ -17,6 +13,10 @@ class TimeoutError(RedisError):
     pass
 
 
+class AuthenticationError(ConnectionError):
+    pass
+
+
 class BusyLoadingError(ConnectionError):
     pass
 
@@ -58,3 +58,8 @@ class LockError(RedisError, ValueError):
     # NOTE: For backwards compatability, this class derives from ValueError.
     # This was originally chosen to behave like threading.Lock.
     pass
+
+
+class LockNotOwnedError(LockError):
+    "Error trying to extend or release a lock that is (no longer) owned"
+    pass
